import type { App } from "@vue/devtools-api/lib/esm/api";
export declare class DevtoolsInstance {
    private api;
    private selectedInspectorNode;
    setup(app: App): void;
    private configurePlugin;
    /**
     * Add all of our stores into the inspector tree(there's no child stores, so it's a single list)
     * @param {HookPayloads[Hooks.GET_INSPECTOR_TREE]} payload
     * @param {Context} context
     * @private
     */
    private onGetInspectorTree;
    /**
     * Handle displaying the inspector state when we click on a store in the list
     *
     * @param {HookPayloads[Hooks.GET_INSPECTOR_STATE]} payload
     * @param {Context} context
     * @private
     */
    private onGetInspectorState;
    /**
     * Handle editing inspector values when we edit them via the custom inspector panel
     *
     * @param {HookPayloads[Hooks.EDIT_INSPECTOR_STATE]} payload
     * @param {Context} context
     * @private
     */
    private onEditInspectorState;
    /**
     * Map our main state object into inspector format(this will render the top list like an object in our inspector panel)
     * @param {{[p: string]: any}} stateData
     * @returns {(StateBase | Omit<ComponentState, "type">)[]}
     * @private
     */
    private mapInspectorState;
    /**
     * Map our regular `get x():z` getters defined on our store into their own "Getters" list on the inspector panel
     *
     * @param {any} store
     * @param {any} instance
     * @param {[key: string, descriptor: PropertyDescriptor][]} allGetters
     * @returns {(StateBase | Omit<ComponentState, "type">)[]}
     * @private
     */
    private mapInspectorGetters;
    /**
     * Map our actions(store methods) into their own "Actions" list on the inspector panel
     *
     * @param {any} instance
     * @param {any} store
     * @returns {(StateBase | Omit<ComponentState, "type">)[]}
     * @private
     */
    private mapInspectorActions;
    /**
     * When we're viewing a component, if we detect a store, we'll override it's state
     * in devtools, so it displays like an object directly rather than the whole
     * class with private methods/properties etc
     *
     * @param {HookPayloads[Hooks.INSPECT_COMPONENT]} payload
     * @param {Context} context
     * @private
     */
    private onInspectComponent;
    private onEditComponentState;
    updateStore(baseStore: any): void;
}
declare const _default: DevtoolsInstance;
export default _default;
